@@ -206,7 +206,7 @@ int32_t SPVM__Sys__IO__fopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
   
   int32_t pointer_fields_length = 1;
-  void* obj_stream = env->new_pointer_with_fields_by_name(env, stack, "Sys::FileStream", stream, pointer_fields_length, &e, FILE_NAME, __LINE__);
+  void* obj_stream = env->new_pointer_with_fields_by_name(env, stack, "Sys::IO::FileStream", stream, pointer_fields_length, &e, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   stack[0].oval = obj_stream;
@@ -234,7 +234,7 @@ int32_t SPVM__Sys__IO__fdopen(SPVM_ENV* env, SPVM_VALUE* stack) {
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
   }
   
-  void* obj_stream = env->new_pointer_by_name(env, stack, "Sys::FileStream", stream, &e, FILE_NAME, __LINE__);
+  void* obj_stream = env->new_pointer_by_name(env, stack, "Sys::IO::FileStream", stream, &e, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   stack[0].oval = obj_stream;
@@ -242,48 +242,6 @@ int32_t SPVM__Sys__IO__fdopen(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Sys__IO__freopen(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t e = 0;
-  
-  void* obj_path = stack[0].oval;
-  
-  if (!obj_path) {
-    return env->die(env, stack, "The path must be defined", FILE_NAME, __LINE__);
-  }
-  
-  const char* path = env->get_chars(env, stack, obj_path);
-  
-  void* obj_mode = stack[1].oval;
-  
-  if (!obj_mode) {
-    return env->die(env, stack, "The mode must be defined", FILE_NAME, __LINE__);
-  }
-  
-  const char* mode = env->get_chars(env, stack, obj_mode);
-  
-  void* obj_stream = stack[2].oval;
-  
-  if (!obj_stream) {
-    return env->die(env, stack, "The stream must be defined", FILE_NAME, __LINE__);
-  }
-  
-  FILE* stream = env->get_pointer(env, stack, obj_stream);
-
-  FILE* new_stream = freopen(path, mode, stream);
-  if (!new_stream) {
-    env->die(env, stack, "[System Error]freopen failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
-    return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
-  }
-  
-  void* obj_new_stream = env->new_pointer_by_name(env, stack, "Sys::FileStream", new_stream, &e, FILE_NAME, __LINE__);
-  if (e) { return e; }
-  
-  stack[0].oval = obj_new_stream;
-  
-  return 0;
-}
-
 int32_t SPVM__Sys__IO__fread(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   int32_t e = 0;
@@ -747,7 +705,7 @@ int32_t SPVM__Sys__IO__opendir(SPVM_ENV* env, SPVM_VALUE* stack) {
   }
 
   int32_t pointer_fields_length = 1;
-  void* obj_dir_stream = env->new_pointer_with_fields_by_name(env, stack, "Sys::DirStream", dir_stream, pointer_fields_length, &e, FILE_NAME, __LINE__);
+  void* obj_dir_stream = env->new_pointer_with_fields_by_name(env, stack, "Sys::IO::DirStream", dir_stream, pointer_fields_length, &e, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   stack[0].oval = obj_dir_stream;
@@ -1106,7 +1064,7 @@ int32_t SPVM__Sys__IO__stat(SPVM_ENV* env, SPVM_VALUE* stack) {
   struct stat* stat_buf = env->get_pointer(env, stack, obj_stat);
   
   int32_t status = stat(path, stat_buf);
-  
+
   if (status == -1) {
     env->die(env, stack, "[System Error]stat failed:%s", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM;
